@@ -5,10 +5,10 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"goformation/v4/cloudformation/types"
+	"github.com/awslabs/goformation/v4/cloudformation/types"
 
-	"goformation/v4/cloudformation/cloudformation"
-	"goformation/v4/cloudformation/policies"
+	"github.com/awslabs/goformation/v4/cloudformation/cloudformation"
+	"github.com/awslabs/goformation/v4/cloudformation/policies"
 )
 
 // DBInstance AWS CloudFormation Resource (AWS::RDS::DBInstance)
