@@ -1,7 +1,7 @@
 package transfer
 
 import (
-	"goformation/v4/cloudformation/policies"
+	"github.com/awslabs/goformation/v4/cloudformation/policies"
 )
 
 // Server_Protocol AWS CloudFormation Resource (AWS::Transfer::Server.Protocol)
