@@ -124,6 +124,40 @@ var _ = DescribeTable("Access Entry validation", func(aet accessEntryTest) {
 		expectedErr: `cannot specify accessEntries[0].kubernetesGroups nor accessEntries[0].kubernetesUsername when type is set to FARGATE_LINUX`,
 	}),
 
+	Entry("kubernetesUsername set for non-standard access entry type", accessEntryTest{
+		authenticationMode: ekstypes.AuthenticationModeApiAndConfigMap,
+		accessEntries: []api.AccessEntry{
+			{
+				PrincipalARN:       api.MustParseARN("arn:aws:iam::111122223333:role/role-1"),
+				Type:               "HYBRID_LINUX",
+				KubernetesUsername: "dummy",
+			},
+		},
+
+		expectedErr: `cannot specify accessEntries[0].kubernetesGroups nor accessEntries[0].kubernetesUsername when type is set to HYBRID_LINUX`,
+	}),
+
+	Entry("accessPolicies set for non-standard access entry type", accessEntryTest{
+		authenticationMode: ekstypes.AuthenticationModeApiAndConfigMap,
+		accessEntries: []api.AccessEntry{
+			{
+				PrincipalARN: api.MustParseARN("arn:aws:iam::111122223333:role/role-1"),
+				Type:         "HYBRID_LINUX",
+				AccessPolicies: []api.AccessPolicy{
+					{
+						PolicyARN: api.MustParseARN("arn:aws:eks::aws:cluster-access-policy/AmazonEKSViewPolicy"),
+						AccessScope: api.AccessScope{
+							Type:       ekstypes.AccessScopeTypeNamespace,
+							Namespaces: []string{"default"},
+						},
+					},
+				},
+			},
+		},
+
+		expectedErr: `cannot specify accessEntries[0].accessPolicies when type is set to HYBRID_LINUX`,
+	}),
+
 	Entry("accessPolicies set for non-standard access entry type", accessEntryTest{
 		authenticationMode: ekstypes.AuthenticationModeApiAndConfigMap,
 		accessEntries: []api.AccessEntry{
