@@ -393,6 +393,8 @@ const (
 	NodeVolumeTypeGP3 = "gp3"
 	// NodeVolumeTypeIO1 is Provisioned IOPS SSD
 	NodeVolumeTypeIO1 = "io1"
+	// NodeVolumeTypeIO2 is Provisioned IOPS SSD
+	NodeVolumeTypeIO2 = "io2"
 	// NodeVolumeTypeSC1 is Cold HDD
 	NodeVolumeTypeSC1 = "sc1"
 	// NodeVolumeTypeST1 is Throughput Optimized HDD
@@ -413,6 +415,8 @@ const (
 	DefaultNodeVolumeThroughput = 125
 	// DefaultNodeVolumeIO1IOPS defines the default throughput for io1 volumes, set to the min value
 	DefaultNodeVolumeIO1IOPS = 100
+	// DefaultNodeVolumeIO2IOPS defines the default throughput for io2 volumes, set to the min value
+	DefaultNodeVolumeIO2IOPS = 100
 	// DefaultNodeVolumeGP3IOPS defines the default throughput for gp3, set to the min value
 	DefaultNodeVolumeGP3IOPS = 3000
 )
@@ -536,6 +540,7 @@ func SupportedNodeVolumeTypes() []string {
 		NodeVolumeTypeGP2,
 		NodeVolumeTypeGP3,
 		NodeVolumeTypeIO1,
+		NodeVolumeTypeIO2,
 		NodeVolumeTypeSC1,
 		NodeVolumeTypeST1,
 	}
