@@ -31,6 +31,8 @@ const (
 	MaxThroughput = 1000
 	MinIO1Iops    = DefaultNodeVolumeIO1IOPS
 	MaxIO1Iops    = 64000
+	MinIO2Iops    = DefaultNodeVolumeIO2IOPS
+	MaxIO2Iops    = 256000
 	MinGP3Iops    = DefaultNodeVolumeGP3IOPS
 	MaxGP3Iops    = 16000
 	OneDay        = 86400
@@ -108,14 +110,10 @@ func (c *ClusterConfig) validateRemoteNetworkingConfig() error {
 		return setNonEmpty("remoteNetworkConfig.remoteNodeNetworks")
 	}
 
-	if c.VPC.ID != "" {
-		if rnc.VPCGatewayID.IsSet() {
+	if rnc.VPCGatewayID.IsSet() {
+		if c.VPC.ID != "" {
 			return fmt.Errorf("remoteNetworkConfig.vpcGatewayID is not supported when using pre-existing VPC")
 		}
-	} else {
-		if !rnc.VPCGatewayID.IsSet() {
-			return setNonEmpty("remoteNetworkConfig.vpcGatewayID")
-		}
 		// vpcGatewayId must be either a virtual private gateway or a transit gateway
 		if !rnc.VPCGatewayID.IsTransitGateway() && !rnc.VPCGatewayID.IsVirtualPrivateGateway() {
 			return fmt.Errorf("invalid value %q provided for remoteNetworkConfig.vpcGatewayID; "+
@@ -742,12 +740,13 @@ func validateNodeGroupBase(np NodePool, path string, controlPlaneOnOutposts bool
 
 	if ng.AMIFamily != NodeImageFamilyAmazonLinux2 &&
 		ng.AMIFamily != NodeImageFamilyAmazonLinux2023 &&
+		ng.AMIFamily != NodeImageFamilyBottlerocket &&
 		ng.AMIFamily != "" {
-		// Only AL2 and AL2023 support Inferentia hosts.
+		// Only AL2, AL2023 and Bottlerocket support Inferentia hosts.
 		if instanceutils.IsInferentiaInstanceType(instanceType) {
 			return ErrUnsupportedInstanceTypes("Inferentia", ng.AMIFamily, fmt.Sprintf("please use %s instead", NodeImageFamilyAmazonLinux2))
 		}
-		// Only AL2 and AL2023 support Trainium hosts.
+		// Only AL2, AL2023 and Bottlerocket support Trainium hosts.
 		if instanceutils.IsTrainiumInstanceType(instanceType) {
 			return ErrUnsupportedInstanceTypes("Trainium", ng.AMIFamily, fmt.Sprintf("please use %s instead", NodeImageFamilyAmazonLinux2))
 		}
@@ -777,8 +776,8 @@ func validateNodeGroupBase(np NodePool, path string, controlPlaneOnOutposts bool
 func validateVolumeOpts(ng *NodeGroupBase, path string, controlPlaneOnOutposts bool) error {
 	if ng.VolumeType != nil {
 		volumeType := *ng.VolumeType
-		if ng.VolumeIOPS != nil && !(volumeType == NodeVolumeTypeIO1 || volumeType == NodeVolumeTypeGP3) {
-			return fmt.Errorf("%s.volumeIOPS is only supported for %s and %s volume types", path, NodeVolumeTypeIO1, NodeVolumeTypeGP3)
+		if ng.VolumeIOPS != nil && !(volumeType == NodeVolumeTypeIO1 || volumeType == NodeVolumeTypeIO2 || volumeType == NodeVolumeTypeGP3) {
+			return fmt.Errorf("%s.volumeIOPS is only supported for %s, %s and %s volume types", path, NodeVolumeTypeIO1, NodeVolumeTypeIO2, NodeVolumeTypeGP3)
 		}
 
 		if volumeType == NodeVolumeTypeIO1 {
@@ -787,6 +786,12 @@ func validateVolumeOpts(ng *NodeGroupBase, path string, controlPlaneOnOutposts b
 			}
 		}
 
+		if volumeType == NodeVolumeTypeIO2 {
+			if ng.VolumeIOPS != nil && !(*ng.VolumeIOPS >= MinIO2Iops && *ng.VolumeIOPS <= MaxIO2Iops) {
+				return fmt.Errorf("value for %s.volumeIOPS must be within range %d-%d", path, MinIO2Iops, MaxIO2Iops)
+			}
+		}
+
 		if ng.VolumeThroughput != nil && volumeType != NodeVolumeTypeGP3 {
 			return fmt.Errorf("%s.volumeThroughput is only supported for %s volume type", path, NodeVolumeTypeGP3)
 		}
