@@ -19,7 +19,10 @@ import (
 )
 
 var zoneIDsToAvoid = map[string][]string{
-	api.RegionCNNorth1: {"cnn1-az4"}, // https://github.com/eksctl-io/eksctl/issues/3916
+	api.RegionCNNorth1:   {"cnn1-az4"}, // https://github.com/eksctl-io/eksctl/issues/3916
+	api.RegionUSEast1:    {"use1-az3"},
+	api.RegionUSWest1:    {"usw1-az2"},
+	api.RegionCACentral1: {"cac1-az3"},
 }
 
 func GetAvailabilityZones(ctx context.Context, ec2API awsapi.EC2, region string, spec *api.ClusterConfig) ([]string, error) {
