@@ -20,8 +20,8 @@ import (
 
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 
-	"goformation/v4"
-	gfnt "goformation/v4/cloudformation/types"
+	"github.com/awslabs/goformation/v4"
+	gfnt "github.com/awslabs/goformation/v4/cloudformation/types"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/fakes"
