@@ -4,7 +4,7 @@ import (
 	"context"
 	"fmt"
 
-	"goformation/v4"
+	"github.com/awslabs/goformation/v4"
 
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
