@@ -339,19 +339,21 @@ func (c *ClusterProvider) ClusterTasksForNodeGroups(cfg *api.ClusterConfig, inst
 	for _, ng := range cfg.NodeGroups {
 		clusterRequiresNeuronDevicePlugin = clusterRequiresNeuronDevicePlugin ||
 			api.HasInstanceType(ng, instanceutils.IsNeuronInstanceType)
-		// Only AL2 requires the NVIDIA device plugin
+		// Only AL2/AL2023 requires the NVIDIA device plugin
 		clusterRequiresNvidiaDevicePlugin = clusterRequiresNvidiaDevicePlugin ||
 			(api.HasInstanceType(ng, instanceutils.IsNvidiaInstanceType) &&
-				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2)
+				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2 ||
+				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2023)
 		efaEnabled = efaEnabled || api.IsEnabled(ng.EFAEnabled)
 	}
 	for _, ng := range cfg.ManagedNodeGroups {
 		clusterRequiresNeuronDevicePlugin = clusterRequiresNeuronDevicePlugin ||
 			api.HasInstanceTypeManaged(ng, instanceutils.IsNeuronInstanceType)
-		// Only AL2 requires the NVIDIA device plugin
+		// Only AL2/AL2023 requires the NVIDIA device plugin
 		clusterRequiresNvidiaDevicePlugin = clusterRequiresNvidiaDevicePlugin ||
 			(api.HasInstanceTypeManaged(ng, instanceutils.IsNvidiaInstanceType) &&
-				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2)
+				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2 ||
+				ng.GetAMIFamily() == api.NodeImageFamilyAmazonLinux2023)
 		efaEnabled = efaEnabled || api.IsEnabled(ng.EFAEnabled)
 	}
 	if clusterRequiresNeuronDevicePlugin {
