@@ -3,6 +3,7 @@ package nodebootstrap
 import (
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
+
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/assets"
 )
@@ -14,17 +15,19 @@ const (
 type Ubuntu struct {
 	clusterConfig *api.ClusterConfig
 	np            api.NodePool
+	clusterDNS    string
 }
 
-func NewUbuntuBootstrapper(clusterConfig *api.ClusterConfig, np api.NodePool) *Ubuntu {
+func NewUbuntuBootstrapper(clusterConfig *api.ClusterConfig, np api.NodePool, clusterDNS string) *Ubuntu {
 	return &Ubuntu{
 		clusterConfig: clusterConfig,
 		np:            np,
+		clusterDNS:    clusterDNS,
 	}
 }
 
 func (b *Ubuntu) UserData() (string, error) {
-	body, err := linuxConfig(b.clusterConfig, ubuntuBootScript, assets.BootstrapUbuntuSh, b.np)
+	body, err := linuxConfig(b.clusterConfig, ubuntuBootScript, assets.BootstrapUbuntuSh, b.clusterDNS, b.np)
 	if err != nil {
 		return "", errors.Wrap(err, "encoding user data")
 	}
